/*
 * init.c --
 *
 *	Initialize the extension.
 *
 * Copyright (C) 1999 Andreas Kupries (a.kupries@westend.com)
 * All rights reserved.
 *
 * Permission is hereby granted, without written agreement and without
 * license or royalty fees, to use, copy, modify, and distribute this
 * software and its documentation for any purpose, provided that the
 * above copyright notice and the following two paragraphs appear in
 * all copies of this software.
 *
 * IN NO EVENT SHALL I BE LIABLE TO ANY PARTY FOR DIRECT, INDIRECT, SPECIAL,
 * INCIDENTAL, OR CONSEQUENTIAL DAMAGES ARISING OUT OF THE USE OF THIS
 * SOFTWARE AND ITS DOCUMENTATION, EVEN IF I HAVE BEEN ADVISED OF THE
 * POSSIBILITY OF SUCH DAMAGE.
 *
 * I SPECIFICALLY DISCLAIM ANY WARRANTIES, INCLUDING, BUT NOT LIMITED TO,
 * THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR
 * PURPOSE.  THE SOFTWARE PROVIDED HEREUNDER IS ON AN "AS IS" BASIS, AND
 * I HAVE NO OBLIGATION TO PROVIDE MAINTENANCE, SUPPORT, UPDATES,
 * ENHANCEMENTS, OR MODIFICATIONS.
 *
 * CVS: $Id: init.c,v 1.7 1999/11/20 17:04:06 aku Exp $
 */


#include "ptoolsInt.h"

#define FIND_LIBRARY \
"tcl_findLibrary Parsetools 0.2 0.2 ptInit.tcl PARSETOOLS_LIBRARY ::parsetools::library"

/*
 *------------------------------------------------------*
 *
 *	Parsetools_Init --
 *
 *	------------------------------------------------*
 *	Standard procedure required by 'load'. 
 *	Initializes this extension.
 *	------------------------------------------------*
 *
 *	Sideeffects:
 *		...
 *
 *	Result:
 *		A standard Tcl error code.
 *
 *------------------------------------------------------*
 */

EXPORT (int,Parsetools_Init) (interp)
Tcl_Interp* interp;
{
  if (Tcl_InitStubs(interp, "8.1", 0) == NULL) {
    return TCL_ERROR;
  }

#define NEW_NS(n) \
  Tcl_VarEval (interp, "namespace eval ", (n), " {}", (char*) NULL)

#define DEL_NS(n) \
  Tcl_VarEval (interp, "namespace delete ", (n), (char*) NULL)

  if (TCL_OK != NEW_NS ("::parsetools")) {
    return TCL_ERROR;
  }

#define INIT(proc) \
  if ((proc) (interp) != TCL_OK) { \
    DEL_NS ("::parsetools"); \
    return TCL_ERROR; \
  }

  INIT (PTInit_Token);

#if 0
  INIT (PTInit_Assembler);
#endif

  /*    Future
   *    PTInit_Assemble, PTInit_Compile
   */

  /*
   * At last search and load our script library.
   */

  if (TCL_OK != Tcl_Eval (interp, FIND_LIBRARY)) {
    /* DEL_NS ("::parsetools"); */
    return TCL_ERROR;
  }

  /*
   * Register parsetools utilities as newly available package
   */

  if (Tcl_PkgProvide (interp, "Parsetools", PARSETOOLS_VERSION) != TCL_OK) {
    return TCL_ERROR;
  }

  return TCL_OK;
}

/*
 *------------------------------------------------------*
 *
 *	Parsetools_SafeInit --
 *
 *	------------------------------------------------*
 *	Standard procedure required by 'load'. 
 *	Initializes this extension for a safe interpreter.
 *	------------------------------------------------*
 *
 *	Sideeffects:
 *		As of 'Parsetools_Init'
 *
 *	Result:
 *		A standard Tcl error code.
 *
 *------------------------------------------------------*
 */

EXPORT (int,Parsetools_SafeInit) (interp)
Tcl_Interp* interp;
{
  return Parsetools_Init (interp);
}


