/* -*- c -*-
 *
 * parsetools.h --
 *
 *	Exported interfaces of the parsetools extension.
 *
 * Copyright (C) 1999 Andreas Kupries (a.kupries@westend.com)
 * All rights reserved.
 *
 * Permission is hereby granted, without written agreement and without
 * license or royalty fees, to use, copy, modify, and distribute this
 * software and its documentation for any purpose, provided that the
 * above copyright notice and the following two paragraphs appear in
 * all copies of this software.
 *
 * IN NO EVENT SHALL I BE LIABLE TO ANY PARTY FOR DIRECT, INDIRECT, SPECIAL,
 * INCIDENTAL, OR CONSEQUENTIAL DAMAGES ARISING OUT OF THE USE OF THIS
 * SOFTWARE AND ITS DOCUMENTATION, EVEN IF I HAVE BEEN ADVISED OF THE
 * POSSIBILITY OF SUCH DAMAGE.
 *
 * I SPECIFICALLY DISCLAIM ANY WARRANTIES, INCLUDING, BUT NOT LIMITED TO,
 * THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR
 * PURPOSE.  THE SOFTWARE PROVIDED HEREUNDER IS ON AN "AS IS" BASIS, AND
 * I HAVE NO OBLIGATION TO PROVIDE MAINTENANCE, SUPPORT, UPDATES,
 * ENHANCEMENTS, OR MODIFICATIONS.
 *
 * CVS: $Id: ptools.h,v 1.1.1.1 1999/11/12 19:05:06 aku Exp $
 */


#ifndef PARSETOOLS_H
#define PARSETOOLS_H


#include <tcl.h>
#include <errno.h>

/*
 * Definitions to enable the generation of a DLL under Windows.
 * Taken from 'ftp://ftp.sunlabs.com/pub/tcl/example.zip(example.c)'
 */

#if defined(__WIN32__)
#   define WIN32_LEAN_AND_MEAN
#   include <windows.h>
#   undef WIN32_LEAN_AND_MEAN

/*
 * VC++ has an alternate entry point called DllMain, so we need to rename
 * our entry point.
 */

#ifdef TCL_STORAGE_CLASS
# undef TCL_STORAGE_CLASS
#endif
#ifdef BUILD_Parsetools
# define TCL_STORAGE_CLASS DLLEXPORT
#else
# define TCL_STORAGE_CLASS DLLIMPORT
#endif

#ifndef STATIC_BUILD
#   if defined(_MSC_VER)
#	define EXPORT(a,b) TCL_STORAGE_CLASS a b
#	define DllEntryPoint DllMain
#   else
#	if defined(__BORLANDC__)
#	    define EXPORT(a,b) a _export b
#	else
#	    define EXPORT(a,b) a b
#	endif
#   endif
#else
#   define EXPORT(a,b) a b
#endif
#else
#   define EXPORT(a,b) a b
#endif


/*
 * Initialization interface.
 */

EXPORT (int,Parsetools_Init)     _ANSI_ARGS_ ((Tcl_Interp* interp));
EXPORT (int,Parsetools_SafeInit) _ANSI_ARGS_ ((Tcl_Interp* interp));

/*
 * Traversing tokens.
 * ==================
 *
 * Definition of
 * 1) The signature of a procedure called for every token in a sequence.
 * 2) Special token type definition for comments.
 *    **ATTENTION** These definitions may clash with the tcl core.
 * 3) Two procedures for traversal of the tree implied in a token list,
 *    either in preorder (parent first, then children) or postorder (children
 *    first, then parent).
 */

/* Possible results:
 * TCL_OK:       Continue with successor token.
 * TCL_ERROR:    Abort completely and return the error.
 * TCL_BREAK:    Abort traversal completely, but use OK for loop return code
 * TCL_CONTINUE: Skip current level and resume traversal at successor
 *               in the level before the current. In case of postorder the
 *               traversal is resumed at the parent.
 */

typedef int
PT_TokenProc _ANSI_ARGS_ ((Tcl_Interp*   interp,
			   ClientData clientData /* arbitrary info. */,
			   int        level,
			   Tcl_Token* tokenPtr));

#define PT_TOKEN_COMMENT (512)

EXPORT (int, PT_Traverse) _ANSI_ARGS_ ((Tcl_Interp*   interp,
					Tcl_Token*    tokenPtr,
					int           numTokens,
					int           postorder,
					PT_TokenProc* callback,
					ClientData    clientData));

/*
 * End of exported interface
 */

#undef  TCL_STORAGE_CLASS
#define TCL_STORAGE_CLASS DLLIMPORT

#endif /* PARSETOOLS_H */
