/* -*- c -*-
 *
 * parsetoolsInt.h --
 *
 *	Internal interfaces of the parsetools extension.
 *
 * Copyright (C) 1999 Andreas Kupries (a.kupries@westend.com)
 * All rights reserved.
 *
 * Permission is hereby granted, without written agreement and without
 * license or royalty fees, to use, copy, modify, and distribute this
 * software and its documentation for any purpose, provided that the
 * above copyright notice and the following two paragraphs appear in
 * all copies of this software.
 *
 * IN NO EVENT SHALL I BE LIABLE TO ANY PARTY FOR DIRECT, INDIRECT, SPECIAL,
 * INCIDENTAL, OR CONSEQUENTIAL DAMAGES ARISING OUT OF THE USE OF THIS
 * SOFTWARE AND ITS DOCUMENTATION, EVEN IF I HAVE BEEN ADVISED OF THE
 * POSSIBILITY OF SUCH DAMAGE.
 *
 * I SPECIFICALLY DISCLAIM ANY WARRANTIES, INCLUDING, BUT NOT LIMITED TO,
 * THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR
 * PURPOSE.  THE SOFTWARE PROVIDED HEREUNDER IS ON AN "AS IS" BASIS, AND
 * I HAVE NO OBLIGATION TO PROVIDE MAINTENANCE, SUPPORT, UPDATES,
 * ENHANCEMENTS, OR MODIFICATIONS.
 *
 * CVS: $Id: ptoolsInt.h,v 1.2 1999/11/20 17:04:06 aku Exp $
 */


#ifndef PARSETOOLS_INT_H
#define PARSETOOLS_INT_H

#include "ptools.h"

/*
 * Convenience macros
 */

#define ARGSTR(i)      Tcl_GetStringFromObj (objv [(i)], NULL)
#define ARGSTRN(i,len) Tcl_GetStringFromObj (objv [(i)], &(len))

/* More convenience macros
 * - construction of (nested) lists
 */

#define LIST_ADDOBJ(list,o) \
  res = Tcl_ListObjAppendElement (interp, list, o); \
  if (res != TCL_OK) {                              \
    Tcl_DecrRefCount (list);                        \
    goto error;                                     \
  }

#define LIST_ADDSTR(list,str)      LIST_ADDOBJ (list,Tcl_NewStringObj(str,-1))
#define LIST_ADDFSTR(list,str,len) LIST_ADDOBJ (list,Tcl_NewStringObj(str,len))
#define LIST_ADDINT(list,i)        LIST_ADDOBJ (list,Tcl_NewIntObj(i))



/*
 * A structure for the dynamic creation and management of token lists.
 */

typedef struct PTTokenList {
  Tcl_Token*    tokenPtr;  /* Array of token structures */
  int           numTokens; /* Number of tokens in the array */
} PTTokenList;

void PTInitTokenList _ANSI_ARGS_ ((PTTokenList* t));
void PTFreeTokenList _ANSI_ARGS_ ((PTTokenList* t));
void PTAddTokens     _ANSI_ARGS_ ((PTTokenList* t,
				   Tcl_Token* token, int numTokens));


/* Initialization of the commands in this part of the extension.
 */

int PTInit_Token     _ANSI_ARGS_ ((Tcl_Interp* interp));

#if 0
int PTInit_Assembler _ANSI_ARGS_ ((Tcl_Interp* interp));
#endif

/*
 * End of internal declarations.
 */

#endif /* PARSETOOLS_INT_H */
